==> apache-camel-3.18.7-src.zip: apache-camel-3.18.7/components/camel-saxon/src/test/java/org/apache/camel/builder/saxon/XQueryResourceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.saxon;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class XQueryResourceTest extends CamelTestSupport {

    @Test
    public void testXPathResource() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("London");

        template.sendBody("direct:start", "<person name='James' city='London'/>");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start")
                        .transform().xquery("resource:classpath:myxquery.txt", String.class)
                        .to("mock:result");
            }
        };
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-saxon/src/test/java/org/apache/camel/builder/saxon/XQueryResourceTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.saxon;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class XQueryResourceTest extends CamelTestSupport {

    @Test
    public void testXPathResource() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("London");

        template.sendBody("direct:start", "<person name='James' city='London'/>");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start")
                        .transform().xquery("resource:classpath:myxquery.txt", String.class)
                        .to("mock:result");
            }
        };
    }
}
